This function collects posts based on search terms and structures the data into a dataframe with
the class names "datasource" and "mastodon".
# S3 method for search.mastodon
Collect(
credential,
endpoint,
hashtag = NULL,
instance = NULL,
local = FALSE,
numPosts = 100,
anonymous = TRUE,
retryOnRateLimit = TRUE,
...,
writeToFile = FALSE,
verbose = TRUE
)A tibble object with class names "datasource" and "mastodon".
A credential object generated from Authenticate with class name "mastodon".
API endpoint.
Character string. Specifies a mastodon query to search on e.g #hashtag. Set to NULL for unfiltered public posts. Default is NULL.
Character string. Server to collect posts from. Default is NULL.
Logical. Search the local server or global timeline. FALSE.
Numeric. Specifies how many tweets to be collected. Default is 100.
Logical. Collect public posts without authenticating. Default is TRUE.
Logical. When the API rate-limit is reached should the collection wait and resume when it resets. Default is TRUE.
Arguments passed on to rtoot::get_timeline_hashtag
only_medialogical, Show only statuses with media attached?
min_idcharacter or POSIXct (date time), Return results immediately newer than this id
Logical. Write collected data to file. Default is FALSE.
Logical. Output additional information. Default is TRUE.